@@ -6,7 +6,7 @@ BEGIN {
   $Path::IsDev::Heuristic::Changelog::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Path::IsDev::Heuristic::Changelog::VERSION = '0.6.0';
+  $Path::IsDev::Heuristic::Changelog::VERSION = '1.000000';
 }
 
 # ABSTRACT: Determine if a path contains a C<Changelog> (or similar)
@@ -14,13 +14,23 @@ BEGIN {
 
 
 use Role::Tiny::With;
-with 'Path::IsDev::Role::Heuristic::RegexpFile';
+with 'Path::IsDev::Role::Heuristic', 'Path::IsDev::Role::Matcher::Child::BaseName::MatchRegexp::File';
 
 
 sub basename_regexp {
   return qr/\AChange(s|log)(|[.][^.\s]+)\z/isxm;
 }
 
+
+sub matches {
+  my ( $self, $result_object ) = @_;
+  if ( $self->child_basename_matchregexp_file( $result_object, $self->basename_regexp ) ) {
+    $result_object->result(1);
+    return 1;
+  }
+  return;
+}
+
 1;
 
 __END__
@@ -35,7 +45,7 @@ Path::IsDev::Heuristic::Changelog - Determine if a path contains a C<Changelog>
 
 =head1 VERSION
 
-version 0.6.0
+version 1.000000
 
 =head1 DESCRIPTION
 
@@ -61,12 +71,16 @@ Indicators for this heuristic is the existence of a file such as:
     Changelog           (i)
     Changelog.anyext    (i)
 
+=head2 C<matches>
+
+Returns a match if any child of C<path> exists matching the regexp C<basename_regexp>
+
 =begin MetaPOD::JSON v1.1.0
 
 {
     "namespace":"Path::IsDev::Heuristic::Changelog",
     "interface":"single_class",
-    "does":"Path::IsDev::Role::Heuristic::RegexpFile"
+    "does":[ "Path::IsDev::Role::Heuristic", "Path::IsDev::Role::Matcher::Child::BaseName::MatchRegexp::File" ]
 }
 
 
