@@ -6,17 +6,28 @@ BEGIN {
   $Path::IsDev::Heuristic::Makefile::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Path::IsDev::Heuristic::Makefile::VERSION = '0.6.0';
+  $Path::IsDev::Heuristic::Makefile::VERSION = '1.000000';
 }
 
 
 # ABSTRACT: Determine if a path contains a C<Makefile>
-
 use Role::Tiny::With;
-with 'Path::IsDev::Role::Heuristic::AnyFile';
+with 'Path::IsDev::Role::Heuristic', 'Path::IsDev::Role::Matcher::Child::Exists::Any::File';
 
 
-sub files { return qw( GNUmakefile makefile Makefile ) }
+sub files {
+  return qw( GNUmakefile makefile Makefile );
+}
+
+
+sub matches {
+  my ( $self, $result_object ) = @_;
+  if ( $self->child_exists_any_file( $result_object, $self->files ) ) {
+    $result_object->result(1);
+    return 1;
+  }
+  return;
+}
 
 1;
 
@@ -32,7 +43,7 @@ Path::IsDev::Heuristic::Makefile - Determine if a path contains a C<Makefile>
 
 =head1 VERSION
 
-version 0.6.0
+version 1.000000
 
 =head1 METHODS
 
@@ -44,12 +55,19 @@ Files relevant to this heuristic:
     makefile
     Makefile
 
+=head2 C<matches>
+
+Matches if any of the files in C<files> exist as children of the C<path>
+
 =begin MetaPOD::JSON v1.1.0
 
 {
     "namespace":"Path::IsDev::Heuristic::Makefile",
     "interface":"single_class",
-    "does":"Path::IsDev::Role::Heuristic::AnyFile"
+    "does":[
+        "Path::IsDev::Role::Heuristic",
+        "Path::IsDev::Role::Matcher::Child::Exists::Any::File"
+    ]
 }
 
 
