@@ -6,7 +6,7 @@ BEGIN {
   $Path::IsDev::Heuristic::TestDir::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Path::IsDev::Heuristic::TestDir::VERSION = '0.6.0';
+  $Path::IsDev::Heuristic::TestDir::VERSION = '1.000000';
 }
 
 # ABSTRACT: Determine if a path contains a t/ or xt/ directory
@@ -14,10 +14,22 @@ BEGIN {
 
 use Role::Tiny::With;
 
-with 'Path::IsDev::Role::Heuristic::AnyDir';
+with 'Path::IsDev::Role::Heuristic', 'Path::IsDev::Role::Matcher::Child::Exists::Any::Dir';
 
 
-sub dirs { return qw( t xt ) }
+sub dirs {
+  return qw( xt t );
+}
+
+
+sub matches {
+  my ( $self, $result_object ) = @_;
+  if ( $self->child_exists_any_dir( $result_object, $self->dirs ) ) {
+    $result_object->result(1);
+    return 1;
+  }
+  return;
+}
 
 1;
 
@@ -33,7 +45,7 @@ Path::IsDev::Heuristic::TestDir - Determine if a path contains a t/ or xt/ direc
 
 =head1 VERSION
 
-version 0.6.0
+version 1.000000
 
 =head1 METHODS
 
@@ -44,12 +56,21 @@ Directories relevant to this heuristic:
     t/
     xt/
 
+=head2 C<matches>
+
+    if ( $heuristic->matches( $result_object ) ) {
+        # one of the directories in ->dirs exists
+    }
+
 =begin MetaPOD::JSON v1.1.0
 
 {
     "namespace":"Path::IsDev::Heuristic::TestDir",
     "interface":"single_class",
-    "does":"Path::IsDev::Role::Heuristic::AnyDir"
+    "does":[
+        "Path::IsDev::Role::Heuristic",
+        "Path::IsDev::Role::Matcher::Child::Exists::Any::Dir"
+    ]
 }
 
 
