@@ -6,19 +6,28 @@ BEGIN {
   $Path::IsDev::Heuristic::Tool::Dzil::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Path::IsDev::Heuristic::Tool::Dzil::VERSION = '0.6.0';
+  $Path::IsDev::Heuristic::Tool::Dzil::VERSION = '1.000000';
 }
 
 
 # ABSTRACT: Determine if a path is a Dist::Zilla Source tree
 
-use Role::Tiny::With;
-
-with 'Path::IsDev::Role::Heuristic::AnyFile';
+use Role::Tiny::With qw( with );
+with 'Path::IsDev::Role::Heuristic', 'Path::IsDev::Role::Matcher::Child::Exists::Any::File';
 
 
 sub files { return qw( dist.ini ) }
 
+
+sub matches {
+  my ( $self, $result_object ) = @_;
+  if ( $self->child_exists_any_file( $result_object, $self->files ) ) {
+    $result_object->result(1);
+    return 1;
+  }
+  return;
+}
+
 1;
 
 __END__
@@ -33,7 +42,7 @@ Path::IsDev::Heuristic::Tool::Dzil - Determine if a path is a Dist::Zilla Source
 
 =head1 VERSION
 
-version 0.6.0
+version 1.000000
 
 =head1 METHODS
 
@@ -43,12 +52,19 @@ Files relevant to this heuristic:
 
     dist.ini
 
+=head2 C<matches>
+
+Matches if any of the files in C<files> exist as children of the C<path>
+
 =begin MetaPOD::JSON v1.1.0
 
 {
     "namespace":"Path::IsDev::Heuristic::Tool::Dzil",
     "interface":"single_class",
-    "does":"Path::IsDev::Role::Heuristic::AnyFile"
+    "does":[
+        "Path::IsDev::Role::Heuristic",
+        "Path::IsDev::Role::Matcher::Child::Exists::Any::File"
+    ]
 }
 
 
