@@ -6,18 +6,29 @@ BEGIN {
   $Path::IsDev::Heuristic::VCS::Git::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Path::IsDev::Heuristic::VCS::Git::VERSION = '0.6.0';
+  $Path::IsDev::Heuristic::VCS::Git::VERSION = '1.000000';
 }
 
 
 # ABSTRACT: Determine if a path contains a C<.git> repository
 
 use Role::Tiny::With;
-with 'Path::IsDev::Role::Heuristic::AnyDir';
+
+with 'Path::IsDev::Role::Heuristic', 'Path::IsDev::Role::Matcher::Child::Exists::Any::Dir';
 
 
 sub dirs { return qw( .git ) }
 
+
+sub matches {
+  my ( $self, $result_object ) = @_;
+  if ( $self->child_exists_any_dir( $result_object, $self->dirs ) ) {
+    $result_object->result(1);
+    return 1;
+  }
+  return;
+}
+
 1;
 
 __END__
@@ -32,7 +43,7 @@ Path::IsDev::Heuristic::VCS::Git - Determine if a path contains a C<.git> reposi
 
 =head1 VERSION
 
-version 0.6.0
+version 1.000000
 
 =head1 METHODS
 
@@ -42,12 +53,19 @@ Directories relevant to this heuristic:
 
     .git
 
+=head2 C<matches>
+
+Return a match if any children of C<path> exist called C<.git> and are directories
+
 =begin MetaPOD::JSON v1.1.0
 
 {
     "namespace":"Path::IsDev::Heuristic::VCS::Git",
     "interface":"single_class",
-    "does":"Path::IsDev::Role::Heuristic::AnyDir"
+    "does":[
+        "Path::IsDev::Role::Heuristic",
+        "Path::IsDev::Role::Matcher::Child::Exists::Any::Dir"
+    ]
 }
 
 
