@@ -7,19 +7,28 @@ BEGIN {
   $Path::IsDev::NegativeHeuristic::IsDev::IgnoreFile::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Path::IsDev::NegativeHeuristic::IsDev::IgnoreFile::VERSION = '0.6.0';
+  $Path::IsDev::NegativeHeuristic::IsDev::IgnoreFile::VERSION = '1.000000';
 }
 
 # ABSTRACT: An explicit exclusion file heuristic
 
 
 use Role::Tiny::With;
-with 'Path::IsDev::Role::NegativeHeuristic::AnyFile';
+with 'Path::IsDev::Role::NegativeHeuristic', 'Path::IsDev::Role::Matcher::Child::Exists::Any::File';
 
 
 sub excludes_files {
   return ('.path_isdev_ignore');
 }
+
+
+sub excludes {
+  my ( $self, $result_object ) = @_;
+  if ( my $result = $self->child_exists_any_file( $result_object, $self->excludes_files ) ) {
+    return 1;
+  }
+  return;
+}
 1;
 
 __END__
@@ -34,7 +43,7 @@ Path::IsDev::NegativeHeuristic::IsDev::IgnoreFile - An explicit exclusion file h
 
 =head1 VERSION
 
-version 0.6.0
+version 1.000000
 
 =head1 SYNOPSIS
 
@@ -66,12 +75,19 @@ Files valid for triggering this heuristic:
 
     .path_isdev_ignore
 
+=head2 C<excludes>
+
+Returns an exclusion if any of C<excludes_files> exists, and are files.
+
 =begin MetaPOD::JSON v1.1.0
 
 {
     "namespace":"Path::IsDev::NegativeHeuristic::IsDev::IgnoreFile",
     "interface":"single_class",
-    "does":"Path::IsDev::Role::NegativeHeuristic::AnyFile"
+    "does":[
+        "Path::IsDev::Role::NegativeHeuristic",
+        "Path::IsDev::Role::Matcher::Child::Exists::Any::File"
+    ]
 }
 
 
