@@ -6,25 +6,30 @@ BEGIN {
   $Path::IsDev::Role::Heuristic::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Path::IsDev::Role::Heuristic::VERSION = '0.6.0';
+  $Path::IsDev::Role::Heuristic::VERSION = '1.000000';
 }
 
 # ABSTRACT: Base role for Heuristic things.
 
+sub _blessed { require Scalar::Util; goto &Scalar::Util::blessed }
+
 use Role::Tiny;
 
 
-sub _blessed { require Scalar::Util; goto &Scalar::Util::blessed }
-
 
 sub name {
   my $name = shift;
   $name = _blessed($name) if _blessed($name);
-  $name =~ s/\APath::IsDev::Heuristic:/:/msx;
+  $name =~ s/\APath::IsDev::Heuristic:/+ :/msx;
   return $name;
 }
 
 
+sub heuristic_type {
+  return 'positive heuristic';
+}
+
+
 requires 'matches';
 
 1;
@@ -41,13 +46,13 @@ Path::IsDev::Role::Heuristic - Base role for Heuristic things.
 
 =head1 VERSION
 
-version 0.6.0
+version 1.000000
 
 =head1 ROLE REQUIRES
 
 =head2 C<matches>
 
-Implementing roles must provide this method.
+Implementing classes must provide this method.
 
     return : 1 / undef
              1     -> this path is a development directory as far as this heuristic is concerned
@@ -57,6 +62,12 @@ Implementing roles must provide this method.
         $class         -> method will be invoked on packages, not objects
         $result_object -> will be a Path::IsDev::Result
 
+Additionally, consuming classes B<should> set C<< $result_object->result( 1 ) >> prior to returning true.
+
+Composing roles B<should> also invoke C<< $result_object->add_reason( $self, $result_value, $descriptive_reason_for_result, \%contextinfo ) >>.
+
+See L<< C<Path::IsDev::Result> for details|Path::IsDev::Result >>
+
 =head1 METHODS
 
 =head2 C<name>
@@ -66,7 +77,14 @@ Returns the name to use in debugging.
 By default, this is derived from the classes name
 with the C<PIDH> prefix removed:
 
-    Path::IsDev::Heuristic::Tool::Dzil->name() # → ::Tool::Dzil
+    Path::IsDev::Heuristic::Tool::Dzil->name()
+    → "+ ::Tool::Dzil"
+
+=head2 C<heuristic_type>
+
+Returns a description of the general heuristic type
+
+    positive heuristic
 
 =begin MetaPOD::JSON v1.1.0
 
